@@ -2,7 +2,7 @@ package Hades::Realm::Exporter;
 use strict;
 use warnings;
 use base qw/Hades/;
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 sub new {
 	my ( $cls, %args ) = ( shift(), scalar @_ == 1 ? %{ $_[0] } : @_ );
@@ -32,6 +32,19 @@ sub export {
 	return $self->{export};
 }
 
+sub build_self {
+	my ( $self, $name ) = @_;
+	if ( defined $name ) {
+		if ( ref $name ) {
+			die
+			    qq{Optional[Str]: invalid value $name for variable \$name in method build_self};
+		}
+	}
+
+	return qq|$name|;
+
+}
+
 sub default_export_hash {
 	my ( $self, $mg, $class, $export ) = @_;
 	if ( ( ref($mg) || "" ) =~ m/^(|HASH|ARRAY|SCALAR|CODE|GLOB)$/ ) {
@@ -728,6 +741,12 @@ Instantiate a new Hades::Realm::Exporter object.
 
 	Hades::Realm::Exporter->new
 
+=head2 build_self
+
+call build_self method. Expects param $name to be a Optional[Str].
+
+	$obj->build_self($name)
+
 =head2 default_export_hash
 
 call default_export_hash method. Expects param $mg to be a Object, param $class to be a HashRef, param $export to be a HashRef.
